@@ -1,6 +1,6 @@
 import sys
 import numpy as np
-import scipy
+from scipy.fft import fft
 from joule.utilities import (timestamp_to_human,
                               seconds_to_timestamp)
 
@@ -57,7 +57,7 @@ def sfit4(data, fs):
     t = np.linspace(0, (N - 1) / float(fs), N)
 
     # Estimate frequency using FFT (step b)
-    Fc = scipy.fft(data)
+    Fc = fft(data)
     F = abs(Fc)
     F[0] = 0   # eliminate DC
 
