@@ -41,7 +41,6 @@ ARGS_DESC = """
   |``scale-factor``   | 1.0 | scale result to watts (RMS voltage)
   |``merge``          | yes | [yes|no] use a single output stream for all phases
   |``polar``          | no  | [yes|no] use polar coordinates (mag, angle) or cartesian (P,Q)
-  |``line-freq``      | 60  | line frequency
   |``samp-freq``      | --  | sampling frequency
 
 :inputs:
@@ -197,8 +196,6 @@ class Prep(FilterModule):
                             help="use a single output stream for all phases")
         parser.add_argument("--polar", type=utilities.yesno, default=False,
                             help="use polar coordinates (mag, angle) or cartesian (P,Q)")
-        parser.add_argument("--line-freq", type=int, default=60,
-                            help="sampling frequency in Hz")
         parser.add_argument("--samp-freq", type=int, required=True,
                             help="sampling frequency in Hz")
         parser.add_argument("--goertzel", type=utilities.yesno,
@@ -246,7 +243,6 @@ class Prep(FilterModule):
             data_timestamps = iv_data[:, 0]
             zc_timestamps = zc_data[:, 0]
             samp_freq = parsed_args.samp_freq
-            line_freq = parsed_args.line_freq
 
             # check to make sure the the zc data overlaps with iv data
             # if we lose a voltage signal iv stalls looking for zc data
@@ -364,7 +360,7 @@ class Prep(FilterModule):
                     # Run prep computation
                     idx_max = await prep_period(shifted_min,
                                                 shifted_max,
-                                                angle_shift, line_freq, samp_freq)
+                                                angle_shift, f0, samp_freq)
                     if not idx_max:
                         break
                     processed = idx_max
